@@ -7,6 +7,7 @@ import time
 import random
 import shutil
 import queue
+from collections import Counter
 
 from .functions import remove_duplicate
 from .colors import COLORS, RESET
@@ -55,7 +56,7 @@ class Checker:
 
     def set_proxy_type(self, proxy_choice: int) -> None:
         if proxy_choice == 1:
-            self.proxy_settings["proxy_type"] = "https"
+            self.proxy_settings["proxy_type"] = "http"
         elif proxy_choice == 2:
             self.proxy_settings["proxy_type"] = "socks4"
         elif proxy_choice == 3:
@@ -67,8 +68,18 @@ class Checker:
             lines = message.readlines()
 
         for line in lines:
-            proxy_list.append(line.replace("\n", ""))
+            count = Counter(line)[":"]
+            if count > 1:
+                ip, port, user, pwd = line.strip("\n").split(":")
+                newProxy = f"{user}:{pwd}@{ip}:{port}"
+                proxy_list.append(newProxy)
+            else:
+                proxy_list.append(line.replace("\n", ""))
         proxy = {"http": "%s://%s" % (self.proxy_settings["proxy_type"], random.choice(proxy_list))}
+        proxy = {
+            "http": f'{self.proxy_settings["proxy_type"]}://{random.choice(proxy_list)}',
+            "https": f'{self.proxy_settings["proxy_type"]}://{random.choice(proxy_list)}'
+        }
 
         return proxy
 
